@@ -29,6 +29,13 @@ func install(font *Font, admin bool) error {
 		fontsDir = filepath.Join(os.Getenv("USERPROFILE"), "AppData", "Local", "Microsoft", "Windows", "Fonts")
 	}
 
+	// check if the Fonts folder exists, if not, create it
+	if _, err := os.Stat(fontsDir); os.IsNotExist(err) {
+		if err = os.MkdirAll(fontsDir, 0755); err != nil {
+			return fmt.Errorf("Unable to create fonts directory: %s", err.Error())
+		}
+	}
+
 	fullPath := filepath.Join(fontsDir, font.FileName)
 	// validate if font is already installed, remove it in case it is
 	if _, err := os.Stat(fullPath); err == nil {
@@ -36,15 +43,18 @@ func install(font *Font, admin bool) error {
 			return fmt.Errorf("Unable to remove existing font file: %s", err.Error())
 		}
 	}
+
 	err := os.WriteFile(fullPath, font.Data, 0644)
 	if err != nil {
 		return fmt.Errorf("Unable to write font file: %s", err.Error())
 	}
 
 	// Add registry entry
-	reg := registry.LOCAL_MACHINE
+	var reg = registry.LOCAL_MACHINE
+	var regValue = font.FileName
 	if !admin {
 		reg = registry.CURRENT_USER
+		regValue = fullPath
 	}
 
 	k, err := registry.OpenKey(reg, `SOFTWARE\Microsoft\Windows NT\CurrentVersion\Fonts`, registry.WRITE)
@@ -59,7 +69,7 @@ func install(font *Font, admin bool) error {
 	defer k.Close()
 
 	name := fmt.Sprintf("%v (TrueType)", font.Name)
-	if err = k.SetStringValue(name, font.FileName); err != nil {
+	if err = k.SetStringValue(name, regValue); err != nil {
 		// If this fails, remove the font file as well.
 		if nexterr := os.Remove(fullPath); nexterr != nil {
 			return errors.New("Unable to delete font file after registry key set error")
