@@ -1,9 +1,9 @@
 package segments
 
 import (
-	"github.com/jandedobbeleer/oh-my-posh/constants"
-	"github.com/jandedobbeleer/oh-my-posh/platform"
-	"github.com/jandedobbeleer/oh-my-posh/properties"
+	"github.com/jandedobbeleer/oh-my-posh/src/constants"
+	"github.com/jandedobbeleer/oh-my-posh/src/properties"
+	"github.com/jandedobbeleer/oh-my-posh/src/runtime"
 )
 
 type Dotnet struct {
@@ -16,7 +16,7 @@ func (d *Dotnet) Template() string {
 	return " {{ if .Unsupported }}\uf071{{ else }}{{ .Full }}{{ end }} "
 }
 
-func (d *Dotnet) Init(props properties.Properties, env platform.Environment) {
+func (d *Dotnet) Init(props properties.Properties, env runtime.Environment) {
 	d.language = language{
 		env:        env,
 		props:      props,
