@@ -3,10 +3,11 @@ package template
 import (
 	"testing"
 
-	"github.com/jandedobbeleer/oh-my-posh/src/mock"
-	"github.com/jandedobbeleer/oh-my-posh/src/platform"
+	"github.com/jandedobbeleer/oh-my-posh/src/cache"
+	"github.com/jandedobbeleer/oh-my-posh/src/runtime/mock"
 
 	"github.com/stretchr/testify/assert"
+	testify_ "github.com/stretchr/testify/mock"
 )
 
 func TestGlob(t *testing.T) {
@@ -21,8 +22,9 @@ func TestGlob(t *testing.T) {
 		{Case: "multiple glob", Expected: "NOK", Template: `{{ if or (glob "package.json") (glob "node_modules") }}OK{{ else }}NOK{{ end }}`},
 	}
 
-	env := &mock.MockedEnvironment{}
-	env.On("TemplateCache").Return(&platform.TemplateCache{
+	env := &mock.Environment{}
+	env.On("DebugF", testify_.Anything, testify_.Anything).Return(nil)
+	env.On("TemplateCache").Return(&cache.Template{
 		Env: make(map[string]string),
 	})
 	for _, tc := range cases {
